(function(window, rJS) {
	"use strict";

	function mm2inches (mm)
	{
		return mm / 25.4
	}

	/*
	Options for printing:
	https://chromedevtools.github.io/devtools-protocol/1-3/Page/#method-printToPDF
	*/
	var optionsForPrintToPdf =
	{
		landscape: false,
		displayHeaderFooter: false,
		printBackground: true,
		scale: 1,
		paperWidth: mm2inches(210 /* millimetre */),
		paperHeight: mm2inches(297 /* millimetre */),
		marginTop: mm2inches(10 /* millimetre */),
		marginBottom: mm2inches(10 /* millimetre */),
		marginLeft: mm2inches(10 /* millimetre */),
		marginRight: mm2inches(10 /* millimetre */),
		pageRanges: "",
		headerTemplate: "",
		footerTemplate: "",
		preferCSSPageSize: false
	}

	rJS(window)
	.declareMethod("convert", function(html) {
		var gadget = this;
		var devtools;
		var targetId;
		var sessionId;
		var base64data;
		return gadget.getDeclaredGadget("devtools")
			.push(function (subgadget) {
				return subgadget.getDevtools();
			})
			.push(function (result) {
				devtools = result;
				return devtools.Target.createTarget({url: ""});
			})
			.push(function (result) {
				targetId = result.targetId;
				return devtools.Target.attachToTarget({targetId: targetId, flatten: true});
			})
			.push(function (result) {
				sessionId = result.sessionId;
				return devtools.Target.activateTarget({targetId: targetId});
			})
			.push(function () {
				return devtools.Network.enable();
			})
			.push(function () {
				return devtools.Page.enable();
			})
			.push(function () {
				return devtools.Page.getFrameTree();
			})
			.push(function (result) {
				var frameId = result.frameTree.frame.id;
				return devtools.Page.setDocumentContent({frameId: frameId, html: html});
			})
			.push(function () {
				return devtools.Page.loadEventFired();
			})
			.push(function () {
				return devtools.Page.printToPDF(optionsForPrintToPdf);
			})
			.push(function (result) {
				base64data = result.data;
				return devtools.Target.detachFromTarget({sessionId: sessionId});
			})
			.push(function () {
				return devtools.Target.closeTarget({targetId: targetId});
			})
			.push(function () {
				return base64data;
			})
	})
}(window, rJS));